@@ -24,6 +24,10 @@ register(
     id='BlankEnv-v0',
     entry_point='sensenet.envs.handroid:BlankEnv',
     )
+register(
+    id='TouchWandEnv-v0',
+    entry_point='sensenet.envs.handroid:TouchWandEnv',
+    )
 register(
     id='SurviveEnv-v0',
     entry_point='sensenet.envs.handroid:SurviveEnv',
